package cn.ibizlab.demoapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.demoapi.dto.*;
import cn.ibizlab.demoapi.mapping.*;
import cn.ibizlab.core.sample.domain.IBZ5Order;
import cn.ibizlab.core.sample.service.IIBZ5OrderService;
import cn.ibizlab.core.sample.filter.IBZ5OrderSearchContext;
import cn.ibizlab.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"订单" })
@RestController("DemoAPI-ibz5order")
@RequestMapping("")
public class IBZ5OrderResource {

    @Autowired
    public IIBZ5OrderService ibz5orderService;

    @Autowired
    @Lazy
    public IBZ5OrderMapping ibz5orderMapping;

    @PreAuthorize("hasPermission(this.ibz5orderMapping.toDomain(#ibz5orderdto),'DemoSys-IBZ5Order-Create')")
    @ApiOperation(value = "新建订单", tags = {"订单" },  notes = "新建订单")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders")
    public ResponseEntity<IBZ5OrderDTO> create(@Validated @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
		ibz5orderService.create(domain);
        IBZ5OrderDTO dto = ibz5orderMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.ibz5orderMapping.toDomain(#ibz5orderdtos),'DemoSys-IBZ5Order-Create')")
    @ApiOperation(value = "批量新建订单", tags = {"订单" },  notes = "批量新建订单")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<IBZ5OrderDTO> ibz5orderdtos) {
        ibz5orderService.createBatch(ibz5orderMapping.toDomain(ibz5orderdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-CreateTemp-all')")
    @ApiOperation(value = "CreateTemp", tags = {"订单" },  notes = "CreateTemp")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/{ibz5order_id}/createtemp")
    public ResponseEntity<IBZ5OrderDTO> createTemp(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.createTemp(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-CreateTempMajor-all')")
    @ApiOperation(value = "CreateTempMajor", tags = {"订单" },  notes = "CreateTempMajor")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/{ibz5order_id}/createtempmajor")
    public ResponseEntity<IBZ5OrderDTO> createTempMajor(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.createTempMajor(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @VersionCheck(entity = "ibz5order" , versionfield = "updatedate")
    @PreAuthorize("hasPermission(this.ibz5orderService.get(#ibz5order_id),'DemoSys-IBZ5Order-Update')")
    @ApiOperation(value = "更新订单", tags = {"订单" },  notes = "更新订单")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5orders/{ibz5order_id}")
    public ResponseEntity<IBZ5OrderDTO> update(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
		IBZ5Order domain  = ibz5orderMapping.toDomain(ibz5orderdto);
        domain .setIbz5orderid(ibz5order_id);
		ibz5orderService.update(domain );
		IBZ5OrderDTO dto = ibz5orderMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.ibz5orderService.getIbz5orderByEntities(this.ibz5orderMapping.toDomain(#ibz5orderdtos)),'DemoSys-IBZ5Order-Update')")
    @ApiOperation(value = "批量更新订单", tags = {"订单" },  notes = "批量更新订单")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5orders/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<IBZ5OrderDTO> ibz5orderdtos) {
        ibz5orderService.updateBatch(ibz5orderMapping.toDomain(ibz5orderdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-UpdateTemp-all')")
    @ApiOperation(value = "UpdateTemp", tags = {"订单" },  notes = "UpdateTemp")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5orders/{ibz5order_id}/updatetemp")
    public ResponseEntity<IBZ5OrderDTO> updateTemp(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.updateTemp(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-UpdateTempMajor-all')")
    @ApiOperation(value = "UpdateTempMajor", tags = {"订单" },  notes = "UpdateTempMajor")
	@RequestMapping(method = RequestMethod.PUT, value = "/ibz5orders/{ibz5order_id}/updatetempmajor")
    public ResponseEntity<IBZ5OrderDTO> updateTempMajor(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.updateTempMajor(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasPermission(this.ibz5orderService.get(#ibz5order_id),'DemoSys-IBZ5Order-Remove')")
    @ApiOperation(value = "删除订单", tags = {"订单" },  notes = "删除订单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5orders/{ibz5order_id}")
    public ResponseEntity<Boolean> remove(@PathVariable("ibz5order_id") String ibz5order_id) {
         return ResponseEntity.status(HttpStatus.OK).body(ibz5orderService.remove(ibz5order_id));
    }

    @PreAuthorize("hasPermission(this.ibz5orderService.getIbz5orderByIds(#ids),'DemoSys-IBZ5Order-Remove')")
    @ApiOperation(value = "批量删除订单", tags = {"订单" },  notes = "批量删除订单")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5orders/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        ibz5orderService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-RemoveTemp-all')")
    @ApiOperation(value = "RemoveTemp", tags = {"订单" },  notes = "RemoveTemp")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5orders/{ibz5order_id}/removetemp")
    public ResponseEntity<IBZ5OrderDTO> removeTemp(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.removeTemp(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-RemoveTempMajor-all')")
    @ApiOperation(value = "RemoveTempMajor", tags = {"订单" },  notes = "RemoveTempMajor")
	@RequestMapping(method = RequestMethod.DELETE, value = "/ibz5orders/{ibz5order_id}/removetempmajor")
    public ResponseEntity<IBZ5OrderDTO> removeTempMajor(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.removeTempMajor(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PostAuthorize("hasPermission(this.ibz5orderMapping.toDomain(returnObject.body),'DemoSys-IBZ5Order-Get')")
    @ApiOperation(value = "获取订单", tags = {"订单" },  notes = "获取订单")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/{ibz5order_id}")
    public ResponseEntity<IBZ5OrderDTO> get(@PathVariable("ibz5order_id") String ibz5order_id) {
        IBZ5Order domain = ibz5orderService.get(ibz5order_id);
        IBZ5OrderDTO dto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-GetTemp-all')")
    @ApiOperation(value = "GetTemp", tags = {"订单" },  notes = "GetTemp")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/{ibz5order_id}/gettemp")
    public ResponseEntity<IBZ5OrderDTO> getTemp(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.getTemp(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-GetTempMajor-all')")
    @ApiOperation(value = "GetTempMajor", tags = {"订单" },  notes = "GetTempMajor")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/{ibz5order_id}/gettempmajor")
    public ResponseEntity<IBZ5OrderDTO> getTempMajor(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.getTempMajor(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @ApiOperation(value = "获取订单草稿", tags = {"订单" },  notes = "获取订单草稿")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/getdraft")
    public ResponseEntity<IBZ5OrderDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderMapping.toDto(ibz5orderService.getDraft(new IBZ5Order())));
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-GetDraftTemp-all')")
    @ApiOperation(value = "GetDraftTemp", tags = {"订单" },  notes = "GetDraftTemp")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/getdrafttemp")
    public ResponseEntity<IBZ5OrderDTO> getDraftTemp() {
        IBZ5Order domain =new IBZ5Order();
        domain = ibz5orderService.getDraftTemp(domain);
        IBZ5OrderDTO ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-GetDraftTempMajor-all')")
    @ApiOperation(value = "GetDraftTempMajor", tags = {"订单" },  notes = "GetDraftTempMajor")
	@RequestMapping(method = RequestMethod.GET, value = "/ibz5orders/{ibz5order_id}/getdrafttempmajor")
    public ResponseEntity<IBZ5OrderDTO> getDraftTempMajor(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.getDraftTempMajor(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-BUIAction-all')")
    @ApiOperation(value = "后台界面行为", tags = {"订单" },  notes = "后台界面行为")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/{ibz5order_id}/buiaction")
    public ResponseEntity<IBZ5OrderDTO> bUIAction(@PathVariable("ibz5order_id") String ibz5order_id, @RequestBody IBZ5OrderDTO ibz5orderdto) {
        IBZ5Order domain = ibz5orderMapping.toDomain(ibz5orderdto);
        domain.setIbz5orderid(ibz5order_id);
        domain = ibz5orderService.bUIAction(domain);
        ibz5orderdto = ibz5orderMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderdto);
    }

    @ApiOperation(value = "检查订单", tags = {"订单" },  notes = "检查订单")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody IBZ5OrderDTO ibz5orderdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(ibz5orderService.checkKey(ibz5orderMapping.toDomain(ibz5orderdto)));
    }

    @PreAuthorize("hasPermission(this.ibz5orderMapping.toDomain(#ibz5orderdto),'DemoSys-IBZ5Order-Save')")
    @ApiOperation(value = "保存订单", tags = {"订单" },  notes = "保存订单")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/save")
    public ResponseEntity<Boolean> save(@RequestBody IBZ5OrderDTO ibz5orderdto) {
        return ResponseEntity.status(HttpStatus.OK).body(ibz5orderService.save(ibz5orderMapping.toDomain(ibz5orderdto)));
    }

    @PreAuthorize("hasPermission(this.ibz5orderMapping.toDomain(#ibz5orderdtos),'DemoSys-IBZ5Order-Save')")
    @ApiOperation(value = "批量保存订单", tags = {"订单" },  notes = "批量保存订单")
	@RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<IBZ5OrderDTO> ibz5orderdtos) {
        ibz5orderService.saveBatch(ibz5orderMapping.toDomain(ibz5orderdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchCSDY-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取测试打印", tags = {"订单" } ,notes = "获取测试打印")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchcsdy")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchCSDY(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchCSDY(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchCSDY-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询测试打印", tags = {"订单" } ,notes = "查询测试打印")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchcsdy")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchCSDY(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchCSDY(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchCurState30-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取当前用户已审核", tags = {"订单" } ,notes = "获取当前用户已审核")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchcurstate30")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchCurState30(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchCurState30(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchCurState30-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询当前用户已审核", tags = {"订单" } ,notes = "查询当前用户已审核")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchcurstate30")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchCurState30(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchCurState30(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDDJETJBB-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取订单金额统计报表", tags = {"订单" } ,notes = "获取订单金额统计报表")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchddjetjbb")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchDDJETJBB(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDDJETJBB(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDDJETJBB-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询订单金额统计报表", tags = {"订单" } ,notes = "查询订单金额统计报表")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchddjetjbb")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchDDJETJBB(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDDJETJBB(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDDReport-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取订单报表打印", tags = {"订单" } ,notes = "获取订单报表打印")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchddreport")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchDDReport(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDDReport(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDDReport-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询订单报表打印", tags = {"订单" } ,notes = "查询订单报表打印")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchddreport")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchDDReport(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDDReport(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDYDDMXSJY-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取打印订单明细数据源", tags = {"订单" } ,notes = "获取打印订单明细数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchdyddmxsjy")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchDYDDMXSJY(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDYDDMXSJY(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDYDDMXSJY-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询打印订单明细数据源", tags = {"订单" } ,notes = "查询打印订单明细数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchdyddmxsjy")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchDYDDMXSJY(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDYDDMXSJY(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDefault-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取DEFAULT", tags = {"订单" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchdefault")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchDefault(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDefault(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchDefault-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询DEFAULT", tags = {"订单" } ,notes = "查询DEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchdefault")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchDefault(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchEchartsDefaultDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取图表默认数据源", tags = {"订单" } ,notes = "获取图表默认数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchechartsdefaultdatasource")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchEchartsDefaultDataSource(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchEchartsDefaultDataSource(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchEchartsDefaultDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询图表默认数据源", tags = {"订单" } ,notes = "查询图表默认数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchechartsdefaultdatasource")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchEchartsDefaultDataSource(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchEchartsDefaultDataSource(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchGaugeDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取仪表盘数据源", tags = {"订单" } ,notes = "获取仪表盘数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchgaugedatasource")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchGaugeDataSource(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchGaugeDataSource(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchGaugeDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询仪表盘数据源", tags = {"订单" } ,notes = "查询仪表盘数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchgaugedatasource")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchGaugeDataSource(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchGaugeDataSource(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchGaugeDataSourceByTime-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取仪表数据源（时间）", tags = {"订单" } ,notes = "获取仪表数据源（时间）")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchgaugedatasourcebytime")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchGaugeDataSourceByTime(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchGaugeDataSourceByTime(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchGaugeDataSourceByTime-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询仪表数据源（时间）", tags = {"订单" } ,notes = "查询仪表数据源（时间）")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchgaugedatasourcebytime")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchGaugeDataSourceByTime(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchGaugeDataSourceByTime(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchLOGIC_22-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取当前用户审核通过与全部取消", tags = {"订单" } ,notes = "获取当前用户审核通过与全部取消")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchlogic_22")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchLOGIC_22(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchLOGIC_22(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchLOGIC_22-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询当前用户审核通过与全部取消", tags = {"订单" } ,notes = "查询当前用户审核通过与全部取消")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchlogic_22")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchLOGIC_22(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchLOGIC_22(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchRadarDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取雷达图数据源", tags = {"订单" } ,notes = "获取雷达图数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchradardatasource")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchRadarDataSource(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchRadarDataSource(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchRadarDataSource-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询雷达图数据源", tags = {"订单" } ,notes = "查询雷达图数据源")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchradardatasource")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchRadarDataSource(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchRadarDataSource(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchSHZOrder-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取审核中订单", tags = {"订单" } ,notes = "获取审核中订单")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchshzorder")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchSHZOrder(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchSHZOrder(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchSHZOrder-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询审核中订单", tags = {"订单" } ,notes = "查询审核中订单")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchshzorder")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchSHZOrder(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchSHZOrder(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState10-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取订单状态10", tags = {"订单" } ,notes = "获取订单状态10")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchstate10")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchState10(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState10(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState10-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询订单状态10", tags = {"订单" } ,notes = "查询订单状态10")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchstate10")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchState10(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState10(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState30-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取订单状态30", tags = {"订单" } ,notes = "获取订单状态30")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchstate30")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchState30(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState30(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState30-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询订单状态30", tags = {"订单" } ,notes = "查询订单状态30")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchstate30")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchState30(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState30(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState40-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取订单状态40", tags = {"订单" } ,notes = "获取订单状态40")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchstate40")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchState40(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState40(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchState40-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询订单状态40", tags = {"订单" } ,notes = "查询订单状态40")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchstate40")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchState40(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchState40(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchXECX-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "获取小额查询", tags = {"订单" } ,notes = "获取小额查询")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/fetchxecx")
	public ResponseEntity<List<IBZ5OrderDTO>> fetchXECX(IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchXECX(context) ;
        List<IBZ5OrderDTO> list = ibz5orderMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.CREATED)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','DemoSys-IBZ5Order-searchXECX-all') and hasPermission(#context,'DemoSys-IBZ5Order-Get')")
	@ApiOperation(value = "查询小额查询", tags = {"订单" } ,notes = "查询小额查询")
    @RequestMapping(method= RequestMethod.POST , value="/ibz5orders/searchxecx")
	public ResponseEntity<Page<IBZ5OrderDTO>> searchXECX(@RequestBody IBZ5OrderSearchContext context) {
        Page<IBZ5Order> domains = ibz5orderService.searchXECX(context) ;
	    return ResponseEntity.status(HttpStatus.CREATED)
                .body(new PageImpl(ibz5orderMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    @Autowired
    cn.ibizlab.core.sample.mapping.IBZ5OrderImport importImpMapping;

    @RequestMapping(method = RequestMethod.POST, value = "/ibz5orders/import")
    public ResponseEntity<JSONObject> importData(@RequestParam(value = "config") String config , @RequestBody List<IBZ5Order> dtos){
        JSONObject rs=new JSONObject();
        if(dtos.size()==0){
            rs.put("rst", 1);
            rs.put("msg", "未传入内容");
            return ResponseEntity.status(HttpStatus.NO_CONTENT).body(rs);
        }
        else{
            if(config.equals("Import")){
                rs=ibz5orderService.importData(importImpMapping.toDomain(dtos),1000,false);
            }
            return ResponseEntity.status(HttpStatus.OK).body(rs);
        }
    }
}

